==> nostlan-2.0.0.tgz: package/README.md <==
# <a href="https://www.patreon.com/nostlan"><img src="https://raw.githubusercontent.com/quinton-ashley/nostlan/master/views/img/icon-sm.png" width=24px height=24px></a> Nostlan : a game launcher for emulators!

<img src="https://quinton-ashley.github.io/nostlan-screenshots/nostlan_ad_banner.png">

## A what? What's a "game launcher"?

Nostlan is like the main page of Netflix, but for your video games. Nostlan downloads high quality box art for each game it identifies. Choose a game and press play to launch it with an emulator!

[Nostlan is unlike any other game launcher](https://github.com/quinton-ashley/nostlan/wiki/How-is-Nostlan-different-from-other-front-ends%3F) because it has a minimal [skeuomorphic](https://en.wikipedia.org/wiki/Skeuomorph) UI design that prioritizes box art. Check out the screenshots below!

Systems supported: Arcade, DS, 3DS, GBA, N64, PS2, PS3, PSP, SNES, SEGA Mega Drive/Genesis, Switch, Wii, Wii U, and Xbox 360.

Emulators supported: bsnes, Cemu, Citra, Cxbx-Reloaded, Dolphin, DeSmuME, DS Player, em-fceux, MAME, melonDS, mesen, mupen64plus, mGBA, PCSX2, PPSSPP, RPCS3, Ryujinx, Ryujinx-LDN, snes9x, VBA, webretro, xemu, Xenia, and Yuzu.

## Features

- navigate Nostlan's menus with your mouse, keyboard, or game controller
- automated install of any emulator
- checks multiple database sites for the highest quality box art
- nostalgic UI themes for each supported console
- designed for UHD displays and projectors
- can launch games using standalone emulator apps, not just cores
- most controllers connect to Nostlan automatically, no setup required
- GameCube controller adapter supported with [gca-js](https://github.com/YonicDev/gca-js) via the [contro-ui](https://github.com/quinton-ashley/contro-ui) framework
- cross-platform support for Linux, macOS, and Windows
- menu translations for Spanish, German, Hebrew, Russian, and Dutch
- advanced customization: edit launch commands
- **_[PREMIUM FEATURE]_** backup/sync all your save data to the cloud or local storage device

## Nostlan is free

_[Download Nostlan for free](https://github.com/quinton-ashley/nostlan/releases)_ but if you enjoy the app [please donate](https://www.paypal.me/qashto/20)! Any amount is appreciated. :)

Be sure to join the [Nostlan community Discord server](https://discord.gg/cT2yNC6)!

[Support the development of Nostlan on Patreon](https://www.patreon.com/nostlan) to gain access to premium features!

## Supported Systems and Emulators

Click on an image to see it in full quality 4K!

### Wii, Gamecube, Virtual Console [Dolphin]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/wii.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/wii_LQ.png">
</a></p>

### Wii U [Cemu]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/wiiu.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/wiiu_LQ.png">
</a></p>

### Switch [Yuzu, Ryujinx]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/switch.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/switch_LQ.png">
</a></p>

### 3DS [Citra]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/n3ds.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/n3ds_LQ.png">
</a></p>

### SNES [bsnes, snes9x]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/snes.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/snes_LQ.png">
</a></p>

### Arcade Machines [MAME]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/mame.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/mame_LQ.png">
</a></p>

### NES [Mesen, em-fceux]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/nes.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/nes_LQ.png">
</a></p>

### DS [melonDS, DeSmuME]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/ds.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/ds_LQ.png">
</a></p>

### GBA [mGBA, Visual Boy Advance]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/gba.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/gba_LQ.png">
</a></p>

### PS2 [PCSX2]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/ps2.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/ps2_LQ.png">
</a></p>

### PS3 [RPCS3]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/ps3.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/ps3_LQ.png">
</a></p>

### Xbox 360 [Xenia]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/xbox360.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/xbox360_LQ.png">
</a></p>

## Support the Development of Nostlan!

[Patreon](https://www.patreon.com/nostlan) supporters get premium features for only \\\$1 a month!

- [backup/sync game saves to the cloud or local storage device](https://github.com/quinton-ashley/nostlan/wiki/Backup-Saves-and-Cloud-Save-Syncing)
- [unlock alternate UI theme color palettes](https://github.com/quinton-ashley/nostlan/wiki/Change-Theme)
- [custom UI theming, lets you change the intro loading screens and make your own color palettes](https://github.com/quinton-ashley/nostlan/wiki/Custom-Themes)

Even though I decided to make this project open source and free to use, it still took a lot of work and a long time to develop. If you appreciate my work so far and will continue to use the app please support its development. Thank you!

## How to access Premium Features

Every month, Patreon supporters will be able to see an exclusive post with the monthly donor password unique to that month. When you start Nostlan it will show a donation menu. Select "access premium features" from the donation menu. Copy the monthly donor password from Patreon and paste it into the donor password input. Select "verify password", if the password is correct you will have access to premium features! Passwords are automatically posted each month.

## Learn more about Nostlan on the wiki

<https://github.com/quinton-ashley/nostlan/wiki>

I've put a lot of effort into documenting Nostlan on the wiki. I hope you find it helpful! Go to the wiki to find out more info on these topics:

Adaptive Button Mapping  
Credits  
Config File Editing Guide  
Custom Themes  
Development Info  
Features  
Game Identification  
Hardware Compatibility  
How is Nostlan different from other front ends?  
Image Names to use for Game Art  
Premium Features  
Progress Reports  
Screenshots  
Setting up Nostlan  
Supported Systems and Emulators  
Using Nostlan

## Contact

Contact me on [Discord](https://discord.gg/cT2yNC6) with your comments, question, suggestions, or if you need any general help using the app.

Please report technical issues and make specific feature requests on this project's Github.

## Legal Disclaimer

Although [emulation is legal](https://en.wikipedia.org/wiki/Bleem!), pirating games you do not own is illegal. Nostlan does not condone piracy. Nostlan is open source software that does not infringe on any copyrights of publishers, developers, artists, or texture packers. Anyone asking for or sharing information related to digital piracy on Nostlan's Discord server or GitHub page will be blocked and have their comments removed and flagged.

## COPYRIGHT AND TRADEMARK INFO

Nostlan is not affiliated with Nintendo, Sony, SEGA, or Microsoft. All trademarks and servicemarks referenced in this app are the property of their respective owners.

MAME and the MAME Logo are Copyright © 1997-2023 MAMEDev and contributors. MAME® is a registered trademark of Gregory Ember. Use of the MAME name and logo is done so with the expressed written permission from the trademark owner. For more information, please visit <https://www.mamedev.org>.

Nostlan was created by Quinton Ashley Copyright © 2019-2023. The Nostlan logo images are licensed under [Attribution-NonCommercial-ShareAlike 4.0 International](https://creativecommons.org/licenses/by-nc-sa/4.0/). The template images found in the [nostlan-img repository](https://github.com/quinton-ashley/nostlan-img) are public domain images under the Public Domain License CC0. The Nostlan software itself is open sourced and licensed under the copyleft [GNU GPLv3 license](https://en.wikipedia.org/wiki/GNU_General_Public_License).

![GNU GPLv3 logo](https://www.gnu.org/graphics/gpl-v3-logo.svg)

==> nostlan-2.2.0.tgz: package/README.md <==
# <a href="https://www.patreon.com/nostlan"><img src="https://raw.githubusercontent.com/quinton-ashley/nostlan/master/views/img/icon-sm.png" width=24px height=24px></a> Nostlan : a game launcher for emulators!

<a href="https://quinton-ashley.github.io/nostlan-web">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/nostlan_ad_banner.png">
</a>

[Download Nostlan from the official website](https://quinton-ashley.github.io/nostlan-web)

## What's a "game launcher"?

Nostlan isn't just a fancy file browser for your game files, it brings the console gaming experience to your computer!

### Total emulation noob?

Nostlan's got your back, with its single-click emulator install feature. It's never been easier to get started with emulation!

### Hardcore collector?

A big bookshelf of game boxes is an impressive conversation starter. Having X amount of games on a hard drive? Not so much.

But with Nostlan you can show off your virtual game collection with high quality box assets. Nostlan is [unlike any other game launcher](https://github.com/quinton-ashley/nostlan/wiki/How-is-Nostlan-different-from-other-front-ends%3F) because it has a minimal, [skeuomorphic](https://en.wikipedia.org/wiki/Skeuomorph) UI design that prioritizes box art. Check out the screenshots below. It's like a virtual game room!

### Couch gamer?

Nostlan was designed to be used with a game controller, so you won't have to use a mouse and keyboard if you don't want to. Nostlan's UI uses large text only, making it perfect for a big UHD TV or projector.

### Looking to play retro and modern games?

_Systems supported: Arcade, DS, 3DS, GBA, N64, PS2, PS3, PSP, SNES, SEGA MD/Genesis, **Nintendo Switch**, Wii, Wii U, Xbox, and Xbox 360._

_Emulators supported: bsnes, Cemu, Citra, Cxbx-Reloaded, Dolphin, DeSmuME, DS Player, em-fceux, MAME, melonDS, mesen, mupen64plus, mGBA, PCSX2, PPSSPP, RPCS3, Ryujinx, Ryujinx-LDN, snes9x, VBA, webretro, xemu, Xenia, and **Yuzu**._

## Exclusive Features

- browse the entire app with your mouse, keyboard, or game controller
- automated install of any emulator
- no nonsense setup and configuration
- checks multiple database sites for the highest quality box art
- nostalgic UI themes for each supported console
- designed for big UHD displays and projectors
- most controllers connect to Nostlan automatically, no setup required
- GameCube controller adapter supported with [gca-js](https://github.com/YonicDev/gca-js) via the [contro-ui](https://github.com/quinton-ashley/contro-ui) framework
- menu translations for Spanish, German, Hebrew, Russian, and Dutch
- cross-platform support for Linux, macOS, and Windows
- can launch games using standalone emulator apps, not just cores
- advanced customization: edit launch commands
- **_[PREMIUM FEATURE]_** backup/sync all your save data to the cloud, local storage device, or between your PC and laptop

## Nostlan is free

**[Download Nostlan](https://github.com/quinton-ashley/nostlan/releases)** and join the [Nostlan community Discord](https://discord.gg/cT2yNC6).

**Support the development of Nostlan on [Patreon](https://www.patreon.com/nostlan) to gain access to premium features!**

## Supported Systems and Emulators

Click on an image to see it in full quality 4K resolution.

### Wii, Gamecube, Virtual Console [Dolphin]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/wii.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/wii_LQ.png">
</a></p>

### Wii U [Cemu]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/wiiu.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/wiiu_LQ.png">
</a></p>

### Switch [Yuzu, Ryujinx]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/switch.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/switch_LQ.png">
</a></p>

### 3DS [Citra]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/n3ds.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/n3ds_LQ.png">
</a></p>

### SNES [bsnes, snes9x]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/snes.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/snes_LQ.png">
</a></p>

### Arcade Machines [MAME]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/mame.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/mame_LQ.png">
</a></p>

### NES [Mesen, em-fceux]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/nes.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/nes_LQ.png">
</a></p>

### DS [melonDS, DeSmuME]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/ds.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/ds_LQ.png">
</a></p>

### GBA [mGBA, Visual Boy Advance]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/gba.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/gba_LQ.png">
</a></p>

### PS2 [PCSX2]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/ps2.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/ps2_LQ.png">
</a></p>

### PS3 [RPCS3]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/ps3.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/ps3_LQ.png">
</a></p>

### Xbox 360 [Xenia]

<p><a href="https://quinton-ashley.github.io/nostlan-screenshots/xbox360.png">
<img src="https://quinton-ashley.github.io/nostlan-screenshots/xbox360_LQ.png">
</a></p>

## Support the Development of Nostlan!

[Patreon](https://www.patreon.com/nostlan) supporters get premium features for only \\\$1 a month!

- [backup/sync game saves to the cloud or local storage device](https://github.com/quinton-ashley/nostlan/wiki/Backup-Saves-and-Cloud-Save-Syncing)
- [unlock alternate UI theme color palettes](https://github.com/quinton-ashley/nostlan/wiki/Change-Theme)
- [custom UI theming, lets you change the intro loading screens and make your own color palettes](https://github.com/quinton-ashley/nostlan/wiki/Custom-Themes)

Even though I decided to make this project open source and free to use, it still took a lot of work and a long time to develop. If you appreciate my work so far and will continue to use the app please support its development. Thank you!

## How to access Premium Features

Every month, Patreon supporters will be able to see an exclusive post with the monthly donor password unique to that month. When you start Nostlan it will show a donation menu. Select "access premium features" from the donation menu. Copy the monthly donor password from Patreon and paste it into the donor password input. Select "verify password", if the password is correct you will have access to premium features! Passwords are automatically posted each month.

## Learn more about Nostlan on the wiki

<https://github.com/quinton-ashley/nostlan/wiki>

I've put a lot of effort into documenting Nostlan on the wiki. I hope you find it helpful! Go to the wiki to find out more info on these topics:

Adaptive Button Mapping  
Credits  
Config File Editing Guide  
Custom Themes  
Development Info  
Features  
Game Identification  
Hardware Compatibility  
How is Nostlan different from other front ends?  
Image Names to use for Game Art  
Premium Features  
Progress Reports  
Screenshots  
Setting up Nostlan  
Supported Systems and Emulators  
Using Nostlan

## Contact

Contact me on [Discord](https://discord.gg/cT2yNC6) with your comments, question, suggestions, or if you need any general help using the app.

Please report technical issues and make specific feature requests on this project's Github.

## Legal Disclaimer

Although [emulation is legal](https://en.wikipedia.org/wiki/Bleem!), pirating games you do not own is illegal. Nostlan does not condone piracy. Nostlan is open source software that does not infringe on any copyrights of publishers, developers, artists, or texture packers. Anyone asking for or sharing information related to digital piracy on Nostlan's Discord server or GitHub page will be blocked and have their comments removed and flagged.

## COPYRIGHT AND TRADEMARK INFO

Nostlan is not affiliated with Nintendo, Sony, SEGA, or Microsoft. All trademarks and servicemarks referenced in this app are the property of their respective owners.

MAME and the MAME Logo are Copyright © 1997-2023 MAMEDev and contributors. MAME® is a registered trademark of Gregory Ember. Use of the MAME name and logo is done so with the expressed written permission from the trademark owner. For more information, please visit <https://www.mamedev.org>.

Nostlan was created by Quinton Ashley Copyright © 2019-2023. The Nostlan logo images are licensed under [Attribution-NonCommercial-ShareAlike 4.0 International](https://creativecommons.org/licenses/by-nc-sa/4.0/). The template images found in the [nostlan-img repository](https://github.com/quinton-ashley/nostlan-img) are public domain images under the Public Domain License CC0. The Nostlan software itself is open sourced and licensed under the copyleft [GNU GPLv3 license](https://en.wikipedia.org/wiki/GNU_General_Public_License).

![GNU GPLv3 logo](https://www.gnu.org/graphics/gpl-v3-logo.svg)
